translate.storage.po

Package translate :: Package storage :: Module po |
[hide private]
[frames] | no frames]

# Source Code for Module translate.storage.po

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """A class loader that will load C or Python implementations of the PO class
    23  depending on the USECPO variable.
    24
    25  Use the environment variable USECPO=2 (or 1) to choose the C implementation which
    26  uses Gettext's libgettextpo for high parsing speed.  Otherise the local
    27  Python based parser is used (slower but very well tested)."""
    28
    29  import os
    30  import logging
    31
    32  if os.getenv('USECPO'):
    33      if os.getenv('USECPO') == "1":
    34          logging.info("Using cPO")
    35          from translate.storage.cpo import * # pylint: disable-msg=W0401,W0614
    36      elif os.getenv('USECPO') == "2":
    37          logging.info("Using new cPO")
    38          from translate.storage.fpo import * # pylint: disable-msg=W0401,W0614
    39      else:
    40          logging.info("Using Python PO")
    41          from translate.storage.pypo import * # pylint: disable-msg=W0401,W0614
    42  else:
    43      from translate.storage.pypo import * # pylint: disable-msg=W0401
    44